# CPAGYM: Certified Public Accountant Reinforcement Learning Toolkit智能会计强化学习包
[![](https://raw.githubusercontent.com/accounting-intelligent-ai/cpagym/main/cpagym.png)](https://cpanlp.com)

Redefining [Accounting](https://cpanlp.com/overview/redefine)!
Developed by **Bfsu Intelligent Accounting Team** (c) 2023
[Github](https://github.com/accounting-intelligent-ai/cpagym)

## Install & Import 安装和导入
For detailed installation instructions, see the
[documentation](https://cpanlp.com/documentation).
```python
pip install cpagym
import cpagym as cg
```


Check out: https://cpanlp.com